@@ -71,7 +71,11 @@ class CMUDictCorpusReader(CorpusReader):
         fileids = self._fileids
         if isinstance(fileids, str):
             fileids = [fileids]
-        return concat([self.open(f).read() for f in fileids])
+        contents = []
+        for i in fileids:
+            with self.open(i) as f:
+                contents.append(f.read())
+        return concat(contents)
 
     def words(self):
         """
