@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 # Natural Language Toolkit: SentiWordNet
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Christopher Potts <cgpotts@stanford.edu>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -37,20 +37,19 @@ http://sentiwordnet.isti.cnr.it/
 """
 
 import re
-from nltk.compat import python_2_unicode_compatible
+
 from nltk.corpus.reader import CorpusReader
 
 
-@python_2_unicode_compatible
 class SentiWordNetCorpusReader(CorpusReader):
-    def __init__(self, root, fileids, encoding='utf-8'):
+    def __init__(self, root, fileids, encoding="utf-8"):
         """
         Construct a new SentiWordNet Corpus Reader, using data from
    	the specified file.
         """
         super(SentiWordNetCorpusReader, self).__init__(root, fileids, encoding=encoding)
         if len(self._fileids) != 1:
-            raise ValueError('Exactly one file must be specified')
+            raise ValueError("Exactly one file must be specified")
         self._db = {}
         self._parse_src_file()
 
@@ -61,8 +60,8 @@ class SentiWordNetCorpusReader(CorpusReader):
             fields = [field.strip() for field in re.split(r"\t+", line)]
             try:
                 pos, offset, pos_score, neg_score, synset_terms, gloss = fields
-            except:
-                raise ValueError('Line %s formatted incorrectly: %s\n' % (i, line))
+            except BaseException as e:
+                raise ValueError("Line %s formatted incorrectly: %s\n" % (i, line)) from e
             if pos and offset:
                 offset = int(offset)
                 self._db[(pos, offset)] = (float(pos_score), float(neg_score))
@@ -73,15 +72,15 @@ class SentiWordNetCorpusReader(CorpusReader):
         if tuple(vals) in self._db:
             pos_score, neg_score = self._db[tuple(vals)]
             pos, offset = vals
-            if pos == 's':
-                pos = 'a'
+            if pos == "s":
+                pos = "a"
             synset = wn.synset_from_pos_and_offset(pos, offset)
             return SentiSynset(pos_score, neg_score, synset)
         else:
             synset = wn.synset(vals[0])
             pos = synset.pos()
-            if pos == 's':
-                pos = 'a'
+            if pos == "s":
+                pos = "a"
             offset = synset.offset()
             if (pos, offset) in self._db:
                 pos_score, neg_score = self._db[(pos, offset)]
@@ -109,7 +108,6 @@ class SentiWordNetCorpusReader(CorpusReader):
             yield SentiSynset(pos_score, neg_score, synset)
 
 
-@python_2_unicode_compatible
 class SentiSynset(object):
     def __init__(self, pos_score, neg_score, synset):
         self._pos_score = pos_score
