@@ -6,7 +6,7 @@
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
-"""
+r"""
 Module for incrementally developing simple discourses, and checking for semantic ambiguity,
 consistency and informativeness.
 
@@ -553,8 +553,9 @@ def load_fol(s):
             continue
         try:
             statements.append(Expression.fromstring(line))
-        except Exception:
-            raise ValueError("Unable to parse line %s: %s" % (linenum, line))
+        except Exception as e:
+            raise ValueError("Unable to parse line %s: %s" %
+                             (linenum, line)) from e
     return statements
 
 
