@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Models for first-order languages with lambda
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Ewan Klein <ewan@inf.ed.ac.uk>,
 # URL: <http://nltk.sourceforge.net>
 # For license information, see LICENSE.TXT
@@ -243,13 +243,13 @@ def read_valuation(s, encoding=None):
             continue
         try:
             statements.append(_read_valuation_line(line))
-        except ValueError:
-            raise ValueError("Unable to parse line %s: %s" % (linenum, line))
+        except ValueError as e:
+            raise ValueError("Unable to parse line %s: %s" % (linenum, line)) from e
     return Valuation(statements)
 
 
 class Assignment(dict):
-    """
+    r"""
     A dictionary which represents an assignment of values to variables.
 
     An assigment can only assign values from its domain.
