@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Stemmers
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Steven Tomcavage <stomcava@law.upenn.edu>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -9,13 +9,11 @@
 A word stemmer based on the Lancaster (Paice/Husk) stemming algorithm.
 Paice, Chris D. "Another Stemmer." ACM SIGIR Forum 24.3 (1990): 56-61.
 """
-from __future__ import unicode_literals
 import re
 
 from nltk.stem.api import StemmerI
-from nltk.compat import python_2_unicode_compatible
 
-@python_2_unicode_compatible
+
 class LancasterStemmer(StemmerI):
     """
     Lancaster Stemmer
@@ -54,121 +52,121 @@ class LancasterStemmer(StemmerI):
 
     # The rule list is static since it doesn't change between instances
     default_rule_tuple = (
-        "ai*2.",     # -ia > -   if intact
-        "a*1.",      # -a > -    if intact
-        "bb1.",      # -bb > -b
-        "city3s.",   # -ytic > -ys
-        "ci2>",      # -ic > -
-        "cn1t>",     # -nc > -nt
-        "dd1.",      # -dd > -d
-        "dei3y>",    # -ied > -y
+        "ai*2.",  # -ia > -   if intact
+        "a*1.",  # -a > -    if intact
+        "bb1.",  # -bb > -b
+        "city3s.",  # -ytic > -ys
+        "ci2>",  # -ic > -
+        "cn1t>",  # -nc > -nt
+        "dd1.",  # -dd > -d
+        "dei3y>",  # -ied > -y
         "deec2ss.",  # -ceed >", -cess
-        "dee1.",     # -eed > -ee
-        "de2>",      # -ed > -
-        "dooh4>",    # -hood > -
-        "e1>",       # -e > -
-        "feil1v.",   # -lief > -liev
-        "fi2>",      # -if > -
-        "gni3>",     # -ing > -
-        "gai3y.",    # -iag > -y
-        "ga2>",      # -ag > -
-        "gg1.",      # -gg > -g
-        "ht*2.",     # -th > -   if intact
-        "hsiug5ct.", # -guish > -ct
-        "hsi3>",     # -ish > -
-        "i*1.",      # -i > -    if intact
-        "i1y>",      # -i > -y
-        "ji1d.",     # -ij > -id   --  see nois4j> & vis3j>
-        "juf1s.",    # -fuj > -fus
-        "ju1d.",     # -uj > -ud
-        "jo1d.",     # -oj > -od
-        "jeh1r.",    # -hej > -her
-        "jrev1t.",   # -verj > -vert
-        "jsim2t.",   # -misj > -mit
-        "jn1d.",     # -nj > -nd
-        "j1s.",      # -j > -s
+        "dee1.",  # -eed > -ee
+        "de2>",  # -ed > -
+        "dooh4>",  # -hood > -
+        "e1>",  # -e > -
+        "feil1v.",  # -lief > -liev
+        "fi2>",  # -if > -
+        "gni3>",  # -ing > -
+        "gai3y.",  # -iag > -y
+        "ga2>",  # -ag > -
+        "gg1.",  # -gg > -g
+        "ht*2.",  # -th > -   if intact
+        "hsiug5ct.",  # -guish > -ct
+        "hsi3>",  # -ish > -
+        "i*1.",  # -i > -    if intact
+        "i1y>",  # -i > -y
+        "ji1d.",  # -ij > -id   --  see nois4j> & vis3j>
+        "juf1s.",  # -fuj > -fus
+        "ju1d.",  # -uj > -ud
+        "jo1d.",  # -oj > -od
+        "jeh1r.",  # -hej > -her
+        "jrev1t.",  # -verj > -vert
+        "jsim2t.",  # -misj > -mit
+        "jn1d.",  # -nj > -nd
+        "j1s.",  # -j > -s
         "lbaifi6.",  # -ifiabl > -
-        "lbai4y.",   # -iabl > -y
-        "lba3>",     # -abl > -
-        "lbi3.",     # -ibl > -
-        "lib2l>",    # -bil > -bl
-        "lc1.",      # -cl > c
-        "lufi4y.",   # -iful > -y
-        "luf3>",     # -ful > -
-        "lu2.",      # -ul > -
-        "lai3>",     # -ial > -
-        "lau3>",     # -ual > -
-        "la2>",      # -al > -
-        "ll1.",      # -ll > -l
-        "mui3.",     # -ium > -
-        "mu*2.",     # -um > -   if intact
-        "msi3>",     # -ism > -
-        "mm1.",      # -mm > -m
-        "nois4j>",   # -sion > -j
+        "lbai4y.",  # -iabl > -y
+        "lba3>",  # -abl > -
+        "lbi3.",  # -ibl > -
+        "lib2l>",  # -bil > -bl
+        "lc1.",  # -cl > c
+        "lufi4y.",  # -iful > -y
+        "luf3>",  # -ful > -
+        "lu2.",  # -ul > -
+        "lai3>",  # -ial > -
+        "lau3>",  # -ual > -
+        "la2>",  # -al > -
+        "ll1.",  # -ll > -l
+        "mui3.",  # -ium > -
+        "mu*2.",  # -um > -   if intact
+        "msi3>",  # -ism > -
+        "mm1.",  # -mm > -m
+        "nois4j>",  # -sion > -j
         "noix4ct.",  # -xion > -ct
-        "noi3>",     # -ion > -
-        "nai3>",     # -ian > -
-        "na2>",      # -an > -
-        "nee0.",     # protect  -een
-        "ne2>",      # -en > -
-        "nn1.",      # -nn > -n
-        "pihs4>",    # -ship > -
-        "pp1.",      # -pp > -p
-        "re2>",      # -er > -
-        "rae0.",     # protect  -ear
-        "ra2.",      # -ar > -
-        "ro2>",      # -or > -
-        "ru2>",      # -ur > -
-        "rr1.",      # -rr > -r
-        "rt1>",      # -tr > -t
-        "rei3y>",    # -ier > -y
-        "sei3y>",    # -ies > -y
-        "sis2.",     # -sis > -s
-        "si2>",      # -is > -
-        "ssen4>",    # -ness > -
-        "ss0.",      # protect  -ss
-        "suo3>",     # -ous > -
-        "su*2.",     # -us > -   if intact
-        "s*1>",      # -s > -    if intact
-        "s0.",       # -s > -s
-        "tacilp4y.", # -plicat > -ply
-        "ta2>",      # -at > -
-        "tnem4>",    # -ment > -
-        "tne3>",     # -ent > -
-        "tna3>",     # -ant > -
-        "tpir2b.",   # -ript > -rib
-        "tpro2b.",   # -orpt > -orb
-        "tcud1.",    # -duct > -duc
-        "tpmus2.",   # -sumpt > -sum
+        "noi3>",  # -ion > -
+        "nai3>",  # -ian > -
+        "na2>",  # -an > -
+        "nee0.",  # protect  -een
+        "ne2>",  # -en > -
+        "nn1.",  # -nn > -n
+        "pihs4>",  # -ship > -
+        "pp1.",  # -pp > -p
+        "re2>",  # -er > -
+        "rae0.",  # protect  -ear
+        "ra2.",  # -ar > -
+        "ro2>",  # -or > -
+        "ru2>",  # -ur > -
+        "rr1.",  # -rr > -r
+        "rt1>",  # -tr > -t
+        "rei3y>",  # -ier > -y
+        "sei3y>",  # -ies > -y
+        "sis2.",  # -sis > -s
+        "si2>",  # -is > -
+        "ssen4>",  # -ness > -
+        "ss0.",  # protect  -ss
+        "suo3>",  # -ous > -
+        "su*2.",  # -us > -   if intact
+        "s*1>",  # -s > -    if intact
+        "s0.",  # -s > -s
+        "tacilp4y.",  # -plicat > -ply
+        "ta2>",  # -at > -
+        "tnem4>",  # -ment > -
+        "tne3>",  # -ent > -
+        "tna3>",  # -ant > -
+        "tpir2b.",  # -ript > -rib
+        "tpro2b.",  # -orpt > -orb
+        "tcud1.",  # -duct > -duc
+        "tpmus2.",  # -sumpt > -sum
         "tpec2iv.",  # -cept > -ceiv
-        "tulo2v.",   # -olut > -olv
-        "tsis0.",    # protect  -sist
-        "tsi3>",     # -ist > -
-        "tt1.",      # -tt > -t
-        "uqi3.",     # -iqu > -
-        "ugo1.",     # -ogu > -og
-        "vis3j>",    # -siv > -j
-        "vie0.",     # protect  -eiv
-        "vi2>",      # -iv > -
-        "ylb1>",     # -bly > -bl
-        "yli3y>",    # -ily > -y
-        "ylp0.",     # protect  -ply
-        "yl2>",      # -ly > -
-        "ygo1.",     # -ogy > -og
-        "yhp1.",     # -phy > -ph
-        "ymo1.",     # -omy > -om
-        "ypo1.",     # -opy > -op
-        "yti3>",     # -ity > -
-        "yte3>",     # -ety > -
-        "ytl2.",     # -lty > -l
-        "yrtsi5.",   # -istry > -
-        "yra3>",     # -ary > -
-        "yro3>",     # -ory > -
-        "yfi3.",     # -ify > -
-        "ycn2t>",    # -ncy > -nt
-        "yca3>",     # -acy > -
-        "zi2>",      # -iz > -
-        "zy1s."      # -yz > -ys
+        "tulo2v.",  # -olut > -olv
+        "tsis0.",  # protect  -sist
+        "tsi3>",  # -ist > -
+        "tt1.",  # -tt > -t
+        "uqi3.",  # -iqu > -
+        "ugo1.",  # -ogu > -og
+        "vis3j>",  # -siv > -j
+        "vie0.",  # protect  -eiv
+        "vi2>",  # -iv > -
+        "ylb1>",  # -bly > -bl
+        "yli3y>",  # -ily > -y
+        "ylp0.",  # protect  -ply
+        "yl2>",  # -ly > -
+        "ygo1.",  # -ogy > -og
+        "yhp1.",  # -phy > -ph
+        "ymo1.",  # -omy > -om
+        "ypo1.",  # -opy > -op
+        "yti3>",  # -ity > -
+        "yte3>",  # -ety > -
+        "ytl2.",  # -lty > -l
+        "yrtsi5.",  # -istry > -
+        "yra3>",  # -ary > -
+        "yro3>",  # -ory > -
+        "yfi3.",  # -ify > -
+        "ycn2t>",  # -ncy > -nt
+        "yca3>",  # -acy > -
+        "zi2>",  # -iz > -
+        "zy1s.",  # -yz > -ys
     )
 
     def __init__(self, rule_tuple=None, strip_prefix_flag=False):
@@ -191,7 +189,7 @@ class LancasterStemmer(StemmerI):
         """
         # If there is no argument for the function, use class' own rule tuple.
         rule_tuple = rule_tuple if rule_tuple else self._rule_tuple
-        valid_rule = re.compile("^[a-z]+\*?\d[a-z]*[>\.]?$")
+        valid_rule = re.compile(r"^[a-z]+\*?\d[a-z]*[>\.]?$")
         # Empty any old rules from the rule set before adding new ones
         self.rule_dictionary = {}
 
@@ -224,7 +222,7 @@ class LancasterStemmer(StemmerI):
         """Perform the actual word stemming
         """
 
-        valid_rule = re.compile("^([a-z]+)(\*?)(\d)([a-z]*)([>\.]?)$")
+        valid_rule = re.compile(r"^([a-z]+)(\*?)(\d)([a-z]*)([>\.]?)$")
 
         proceed = True
 
@@ -234,7 +232,10 @@ class LancasterStemmer(StemmerI):
             last_letter_position = self.__getLastLetter(word)
 
             # Only stem the word if it has a last letter and a rule matching that last letter
-            if last_letter_position < 0 or word[last_letter_position] not in self.rule_dictionary:
+            if (
+                last_letter_position < 0
+                or word[last_letter_position] not in self.rule_dictionary
+            ):
                 proceed = False
 
             else:
@@ -244,11 +245,13 @@ class LancasterStemmer(StemmerI):
                 for rule in self.rule_dictionary[word[last_letter_position]]:
                     rule_match = valid_rule.match(rule)
                     if rule_match:
-                        (ending_string,
-                         intact_flag,
-                         remove_total,
-                         append_string,
-                         cont_flag) = rule_match.groups()
+                        (
+                            ending_string,
+                            intact_flag,
+                            remove_total,
+                            append_string,
+                            cont_flag,
+                        ) = rule_match.groups()
 
                         # Convert the number of chars to remove when stemming
                         # from a string to an integer
@@ -257,21 +260,22 @@ class LancasterStemmer(StemmerI):
                         # Proceed if word's ending matches rule's word ending
                         if word.endswith(ending_string[::-1]):
                             if intact_flag:
-                                if (word == intact_word and
-                                    self.__isAcceptable(word, remove_total)):
-                                    word = self.__applyRule(word,
-                                                            remove_total,
-                                                            append_string)
+                                if word == intact_word and self.__isAcceptable(
+                                    word, remove_total
+                                ):
+                                    word = self.__applyRule(
+                                        word, remove_total, append_string
+                                    )
                                     rule_was_applied = True
-                                    if cont_flag == '.':
+                                    if cont_flag == ".":
                                         proceed = False
                                     break
                             elif self.__isAcceptable(word, remove_total):
-                                word = self.__applyRule(word,
-                                                        remove_total,
-                                                        append_string)
+                                word = self.__applyRule(
+                                    word, remove_total, append_string
+                                )
                                 rule_was_applied = True
-                                if cont_flag == '.':
+                                if cont_flag == ".":
                                     proceed = False
                                 break
                 # If no rules apply, the word doesn't need any more stemming
@@ -297,18 +301,17 @@ class LancasterStemmer(StemmerI):
         # If the word starts with a vowel, it must be at least 2
         # characters long to be stemmed
         if word[0] in "aeiouy":
-            if (len(word) - remove_total >= 2):
+            if len(word) - remove_total >= 2:
                 word_is_acceptable = True
         # If the word starts with a consonant, it must be at least 3
         # characters long (including one vowel) to be stemmed
-        elif (len(word) - remove_total >= 3):
+        elif len(word) - remove_total >= 3:
             if word[1] in "aeiouy":
                 word_is_acceptable = True
             elif word[2] in "aeiouy":
                 word_is_acceptable = True
         return word_is_acceptable
 
-
     def __applyRule(self, word, remove_total, append_string):
         """Apply the stemming rule to the word
         """
@@ -327,11 +330,20 @@ class LancasterStemmer(StemmerI):
         This function originally taken from Whoosh.
 
         """
-        for prefix in ("kilo", "micro", "milli", "intra", "ultra", "mega",
-                       "nano", "pico", "pseudo"):
+        for prefix in (
+            "kilo",
+            "micro",
+            "milli",
+            "intra",
+            "ultra",
+            "mega",
+            "nano",
+            "pico",
+            "pseudo",
+        ):
             if word.startswith(prefix):
-                return word[len(prefix):]
+                return word[len(prefix) :]
         return word
 
     def __repr__(self):
-        return '<LancasterStemmer>'
+        return "<LancasterStemmer>"
