@@ -275,12 +275,11 @@ class PerceptronTagger(TaggerI):
         """
         if "-" in word and word[0] != "-":
             return "!HYPHEN"
-        elif word.isdigit() and len(word) == 4:
+        if word.isdigit() and len(word) == 4:
             return "!YEAR"
-        elif word[0].isdigit():
+        if word and word[0].isdigit():
             return "!DIGITS"
-        else:
-            return word.lower()
+        return word.lower()
 
     def _get_features(self, i, word, context, prev, prev2):
         """Map tokens into a feature representation, implemented as a
@@ -296,7 +295,7 @@ class PerceptronTagger(TaggerI):
         # It's useful to have a constant feature, which acts sort of like a prior
         add("bias")
         add("i suffix", word[-3:])
-        add("i pref1", word[0])
+        add("i pref1", word[0] if word else "")
         add("i-1 tag", prev)
         add("i-2 tag", prev2)
         add("i tag+i-2 tag", prev, prev2)
