@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Sequential Backoff Taggers
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Steven Bird <stevenbird1@gmail.com> (minor additions)
 #         Tiago Tresoldi <tresoldi@users.sf.net> (original affix tagger)
@@ -540,7 +540,8 @@ class RegexpTagger(SequentialBackoffTagger):
             self._regexps = [(re.compile(regexp), tag,) for regexp, tag in regexps]
         except Exception as e:
             raise Exception(
-                'Invalid RegexpTagger regexp:', str(e), 'regexp:', regexp, 'tag:', tag)
+                'Invalid RegexpTagger regexp:', str(e), 'regexp:', regexp, 'tag:', tag
+            ) from e
 
     def encode_json_obj(self):
         return [(regexp.pattern, tag) for regexp, tag in self._regexps], self.backoff
@@ -719,15 +720,15 @@ class ClassifierBasedPOSTagger(ClassifierBasedTagger):
             prevtag = history[index - 1]
             prevprevtag = history[index - 2]
 
-        if re.match("[0-9]+(\.[0-9]*)?|[0-9]*\.[0-9]+$", word):
+        if re.match(r"[0-9]+(\.[0-9]*)?|[0-9]*\.[0-9]+$", word):
             shape = "number"
-        elif re.match("\W+$", word):
+        elif re.match(r"\W+$", word):
             shape = "punct"
         elif re.match("[A-Z][a-z]+$", word):
             shape = "upcase"
         elif re.match("[a-z]+$", word):
             shape = "downcase"
-        elif re.match("\w+$", word):
+        elif re.match(r"\w+$", word):
             shape = "mixedcase"
         else:
             shape = "other"
