@@ -1,14 +1,14 @@
 # -*- coding: utf-8 -*-
 
 
-def setup_module(module):
-    from nose import SkipTest
+def setup_module():
+    import pytest
     from nltk.inference.mace import Mace
 
     try:
         m = Mace()
         m._find_binary("mace4")
     except LookupError:
-        raise SkipTest(
+        pytest.skip(
             "Mace4/Prover9 is not available so inference.doctest was skipped"
         )
