@@ -21,9 +21,5 @@ def test_basic():
 
 
 def setup_module(module):
-    from nose import SkipTest
-
-    try:
-        import numpy
-    except ImportError:
-        raise SkipTest("numpy is required for nltk.test.test_tag")
+    import pytest
+    pytest.importorskip("numpy")
