@@ -3,7 +3,7 @@
 #
 # Natural Language Toolkit: TGrep search
 #
-# Copyright (C) 2001-2020 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Author: Will Roberts <wildwilhelm@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -781,7 +781,3 @@ class TestSequenceFunctions(unittest.TestCase):
         self.assertEqual(
             list(tgrep.tgrep_positions('NN;;', [tree])), [[(0, 2), (2, 1)]]
         )
-
-
-if __name__ == '__main__':
-    unittest.main()
