@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Punkt sentence tokenizer
 #
-# Copyright (C) 2001-2019 NLTK Project
+# Copyright (C) 2001-2021 NLTK Project
 # Algorithm: Kiss & Strunk (2006)
 # Author: Willy <willy@csse.unimelb.edu.au> (original Python port)
 #         Steven Bird <stevenbird1@gmail.com> (additions)
@@ -99,7 +99,6 @@ The algorithm for this tokenizer is described in::
   Kiss, Tibor and Strunk, Jan (2006): Unsupervised Multilingual Sentence
     Boundary Detection.  Computational Linguistics 32: 485-525.
 """
-from __future__ import print_function, unicode_literals, division
 
 # TODO: Make orthographic heuristic less susceptible to overtraining
 # TODO: Frequent sentence starters optionally exclude always-capitalised words
@@ -109,9 +108,6 @@ import re
 import math
 from collections import defaultdict
 
-from six import string_types
-
-from nltk.compat import unicode_repr, python_2_unicode_compatible
 from nltk.probability import FreqDist
 from nltk.tokenize.api import TokenizerI
 
@@ -147,12 +143,12 @@ _ORTHO_LC = _ORTHO_BEG_LC + _ORTHO_MID_LC + _ORTHO_UNK_LC
 """Orthographic context: occurs with lower case."""
 
 _ORTHO_MAP = {
-    ('initial', 'upper'): _ORTHO_BEG_UC,
-    ('internal', 'upper'): _ORTHO_MID_UC,
-    ('unknown', 'upper'): _ORTHO_UNK_UC,
-    ('initial', 'lower'): _ORTHO_BEG_LC,
-    ('internal', 'lower'): _ORTHO_MID_LC,
-    ('unknown', 'lower'): _ORTHO_UNK_LC,
+    ("initial", "upper"): _ORTHO_BEG_UC,
+    ("internal", "upper"): _ORTHO_MID_UC,
+    ("unknown", "upper"): _ORTHO_UNK_UC,
+    ("initial", "lower"): _ORTHO_BEG_LC,
+    ("internal", "lower"): _ORTHO_MID_LC,
+    ("unknown", "lower"): _ORTHO_UNK_LC,
 }
 """A map from context position and first-letter case to the
 appropriate orthographic context flag."""
@@ -164,14 +160,14 @@ appropriate orthographic context flag."""
 # { Decision reasons for debugging
 ######################################################################
 
-REASON_DEFAULT_DECISION = 'default decision'
-REASON_KNOWN_COLLOCATION = 'known collocation (both words)'
-REASON_ABBR_WITH_ORTHOGRAPHIC_HEURISTIC = 'abbreviation + orthographic heuristic'
-REASON_ABBR_WITH_SENTENCE_STARTER = 'abbreviation + frequent sentence starter'
-REASON_INITIAL_WITH_ORTHOGRAPHIC_HEURISTIC = 'initial + orthographic heuristic'
-REASON_NUMBER_WITH_ORTHOGRAPHIC_HEURISTIC = 'initial + orthographic heuristic'
+REASON_DEFAULT_DECISION = "default decision"
+REASON_KNOWN_COLLOCATION = "known collocation (both words)"
+REASON_ABBR_WITH_ORTHOGRAPHIC_HEURISTIC = "abbreviation + orthographic heuristic"
+REASON_ABBR_WITH_SENTENCE_STARTER = "abbreviation + frequent sentence starter"
+REASON_INITIAL_WITH_ORTHOGRAPHIC_HEURISTIC = "initial + orthographic heuristic"
+REASON_NUMBER_WITH_ORTHOGRAPHIC_HEURISTIC = "initial + orthographic heuristic"
 REASON_INITIAL_WITH_SPECIAL_ORTHOGRAPHIC_HEURISTIC = (
-    'initial + special orthographic heuristic'
+    "initial + special orthographic heuristic"
 )
 
 
@@ -193,7 +189,7 @@ class PunktLanguageVars(object):
     constructors.
     """
 
-    __slots__ = ('_re_period_context', '_re_word_tokenizer')
+    __slots__ = ("_re_period_context", "_re_word_tokenizer")
 
     def __getstate__(self):
         # All modifications to the class are performed by inheritance.
@@ -204,14 +200,14 @@ class PunktLanguageVars(object):
     def __setstate__(self, state):
         return 1
 
-    sent_end_chars = ('.', '?', '!')
+    sent_end_chars = (".", "?", "!")
     """Characters which are candidates for sentence boundaries"""
 
     @property
     def _re_sent_end_chars(self):
-        return '[%s]' % re.escape(''.join(self.sent_end_chars))
+        return "[%s]" % re.escape("".join(self.sent_end_chars))
 
-    internal_punctuation = ',:;'  # might want to extend this..
+    internal_punctuation = ",:;"  # might want to extend this..
     """sentence internal punctuation, which indicates an abbreviation if
     preceded by a period-final token."""
 
@@ -222,13 +218,15 @@ class PunktLanguageVars(object):
     _re_word_start = r"[^\(\"\`{\[:;&\#\*@\)}\]\-,]"
     """Excludes some characters from starting word tokens"""
 
-    _re_non_word_chars = r"(?:[?!)\";}\]\*:@\'\({\[])"
+    @property
+    def _re_non_word_chars(self):
+        return "(?:[)\";}\]\*:@\'\({\[%s])" % re.escape("".join(set(self.sent_end_chars) - {"."}))
     """Characters that cannot appear within words"""
 
     _re_multi_char_punct = r"(?:\-{2,}|\.{2,}|(?:\.\s){2,}\.)"
     """Hyphen and ellipsis are multi-character punctuation"""
 
-    _word_tokenize_fmt = r'''(
+    _word_tokenize_fmt = r"""(
         %(MultiChar)s
         |
         (?=%(WordStart)s)\S+?  # Accept word characters until end is found
@@ -240,7 +238,7 @@ class PunktLanguageVars(object):
         )
         |
         \S
-    )'''
+    )"""
     """Format of a regular expression to split punctuation from words,
     excluding period."""
 
@@ -252,9 +250,9 @@ class PunktLanguageVars(object):
             self._re_word_tokenizer = re.compile(
                 self._word_tokenize_fmt
                 % {
-                    'NonWord': self._re_non_word_chars,
-                    'MultiChar': self._re_multi_char_punct,
-                    'WordStart': self._re_word_start,
+                    "NonWord": self._re_non_word_chars,
+                    "MultiChar": self._re_multi_char_punct,
+                    "WordStart": self._re_word_start,
                 },
                 re.UNICODE | re.VERBOSE,
             )
@@ -285,15 +283,15 @@ class PunktLanguageVars(object):
             self._re_period_context = re.compile(
                 self._period_context_fmt
                 % {
-                    'NonWord': self._re_non_word_chars,
-                    'SentEndChars': self._re_sent_end_chars,
+                    "NonWord": self._re_non_word_chars,
+                    "SentEndChars": self._re_sent_end_chars,
                 },
                 re.UNICODE | re.VERBOSE,
             )
             return self._re_period_context
 
 
-_re_non_punct = re.compile(r'[^\W\d]', re.UNICODE)
+_re_non_punct = re.compile(r"[^\W\d]", re.UNICODE)
 """Matches token types that are not merely punctuation. (Types for
 numeric tokens are changed to ##number## and hence contain alpha.)"""
 
@@ -370,17 +368,17 @@ class PunktParameters(object):
     def _debug_ortho_context(self, typ):
         c = self.ortho_context[typ]
         if c & _ORTHO_BEG_UC:
-            yield 'BEG-UC'
+            yield "BEG-UC"
         if c & _ORTHO_MID_UC:
-            yield 'MID-UC'
+            yield "MID-UC"
         if c & _ORTHO_UNK_UC:
-            yield 'UNK-UC'
+            yield "UNK-UC"
         if c & _ORTHO_BEG_LC:
-            yield 'BEG-LC'
+            yield "BEG-LC"
         if c & _ORTHO_MID_LC:
-            yield 'MID-LC'
+            yield "MID-LC"
         if c & _ORTHO_UNK_LC:
-            yield 'UNK-LC'
+            yield "UNK-LC"
 
 
 ######################################################################
@@ -388,18 +386,17 @@ class PunktParameters(object):
 ######################################################################
 
 
-@python_2_unicode_compatible
 class PunktToken(object):
     """Stores a token of text with annotations produced during
     sentence boundary detection."""
 
-    _properties = ['parastart', 'linestart', 'sentbreak', 'abbr', 'ellipsis']
-    __slots__ = ['tok', 'type', 'period_final'] + _properties
+    _properties = ["parastart", "linestart", "sentbreak", "abbr", "ellipsis"]
+    __slots__ = ["tok", "type", "period_final"] + _properties
 
     def __init__(self, tok, **params):
         self.tok = tok
         self.type = self._get_type(tok)
-        self.period_final = tok.endswith('.')
+        self.period_final = tok.endswith(".")
 
         for p in self._properties:
             setattr(self, p, None)
@@ -410,10 +407,10 @@ class PunktToken(object):
     # { Regular expressions for properties
     # ////////////////////////////////////////////////////////////
     # Note: [A-Za-z] is approximated by [^\W\d] in the general case.
-    _RE_ELLIPSIS = re.compile(r'\.\.+$')
-    _RE_NUMERIC = re.compile(r'^-?[\.,]?\d[\d,\.-]*\.?$')
-    _RE_INITIAL = re.compile(r'[^\W\d]\.$', re.UNICODE)
-    _RE_ALPHA = re.compile(r'[^\W\d]+$', re.UNICODE)
+    _RE_ELLIPSIS = re.compile(r"\.\.+$")
+    _RE_NUMERIC = re.compile(r"^-?[\.,]?\d[\d,\.-]*\.?$")
+    _RE_INITIAL = re.compile(r"[^\W\d]\.$", re.UNICODE)
+    _RE_ALPHA = re.compile(r"[^\W\d]+$", re.UNICODE)
 
     # ////////////////////////////////////////////////////////////
     # { Derived properties
@@ -421,14 +418,14 @@ class PunktToken(object):
 
     def _get_type(self, tok):
         """Returns a case-normalized representation of the token."""
-        return self._RE_NUMERIC.sub('##number##', tok.lower())
+        return self._RE_NUMERIC.sub("##number##", tok.lower())
 
     @property
     def type_no_period(self):
         """
         The type with its final period removed if it has one.
         """
-        if len(self.type) > 1 and self.type[-1] == '.':
+        if len(self.type) > 1 and self.type[-1] == ".":
             return self.type[:-1]
         return self.type
 
@@ -455,10 +452,10 @@ class PunktToken(object):
     @property
     def first_case(self):
         if self.first_lower:
-            return 'lower'
+            return "lower"
         elif self.first_upper:
-            return 'upper'
-        return 'none'
+            return "upper"
+        return "none"
 
     @property
     def is_ellipsis(self):
@@ -468,7 +465,7 @@ class PunktToken(object):
     @property
     def is_number(self):
         """True if the token text is that of a number."""
-        return self.type.startswith('##number##')
+        return self.type.startswith("##number##")
 
     @property
     def is_initial(self):
@@ -495,17 +492,17 @@ class PunktToken(object):
         with eval(), which lists all the token's non-default
         annotations.
         """
-        typestr = ' type=%s,' % unicode_repr(self.type) if self.type != self.tok else ''
+        typestr = " type=%s," % repr(self.type) if self.type != self.tok else ""
 
-        propvals = ', '.join(
-            '%s=%s' % (p, unicode_repr(getattr(self, p)))
+        propvals = ", ".join(
+            "%s=%s" % (p, repr(getattr(self, p)))
             for p in self._properties
             if getattr(self, p)
         )
 
-        return '%s(%s,%s %s)' % (
+        return "%s(%s,%s %s)" % (
             self.__class__.__name__,
-            unicode_repr(self.tok),
+            repr(self.tok),
             typestr,
             propvals,
         )
@@ -516,11 +513,11 @@ class PunktToken(object):
         """
         res = self.tok
         if self.abbr:
-            res += '<A>'
+            res += "<A>"
         if self.ellipsis:
-            res += '<E>'
+            res += "<E>"
         if self.sentbreak:
-            res += '<S>'
+            res += "<S>"
         return res
 
 
@@ -558,7 +555,7 @@ class PunktBaseClass(object):
         respectively.
         """
         parastart = False
-        for line in plaintext.split('\n'):
+        for line in plaintext.split("\n"):
             if line.strip():
                 line_toks = iter(self._lang_vars.word_tokenize(line))
 
@@ -611,10 +608,10 @@ class PunktBaseClass(object):
             aug_tok.sentbreak = True
         elif aug_tok.is_ellipsis:
             aug_tok.ellipsis = True
-        elif aug_tok.period_final and not tok.endswith('..'):
+        elif aug_tok.period_final and not tok.endswith(".."):
             if (
                 tok[:-1].lower() in self._params.abbrev_types
-                or tok[:-1].lower().split('-')[-1] in self._params.abbrev_types
+                or tok[:-1].lower().split("-")[-1] in self._params.abbrev_types
             ):
 
                 aug_tok.abbr = True
@@ -768,12 +765,12 @@ class PunktTrainer(PunktBaseClass):
                 if is_add:
                     self._params.abbrev_types.add(abbr)
                     if verbose:
-                        print(('  Abbreviation: [%6.4f] %s' % (score, abbr)))
+                        print(("  Abbreviation: [%6.4f] %s" % (score, abbr)))
             else:
                 if not is_add:
                     self._params.abbrev_types.remove(abbr)
                     if verbose:
-                        print(('  Removed abbreviation: [%6.4f] %s' % (score, abbr)))
+                        print(("  Removed abbreviation: [%6.4f] %s" % (score, abbr)))
 
         # Make a preliminary pass through the document, marking likely
         # sentence breaks, abbreviations, and ellipsis tokens.
@@ -796,7 +793,7 @@ class PunktTrainer(PunktBaseClass):
             if self._is_rare_abbrev_type(aug_tok1, aug_tok2):
                 self._params.abbrev_types.add(aug_tok1.type_no_period)
                 if verbose:
-                    print(('  Rare Abbrev: %s' % aug_tok1.type))
+                    print(("  Rare Abbrev: %s" % aug_tok1.type))
 
             # Does second token have a high likelihood of starting a sentence?
             if self._is_potential_sent_starter(aug_tok2, aug_tok1):
@@ -820,13 +817,13 @@ class PunktTrainer(PunktBaseClass):
         for typ, ll in self._find_sent_starters():
             self._params.sent_starters.add(typ)
             if verbose:
-                print(('  Sent Starter: [%6.4f] %r' % (ll, typ)))
+                print(("  Sent Starter: [%6.4f] %r" % (ll, typ)))
 
         self._params.clear_collocations()
         for (typ1, typ2), ll in self._find_collocations():
             self._params.collocations.add((typ1, typ2))
             if verbose:
-                print(('  Collocation: [%6.4f] %r+%r' % (ll, typ1, typ2)))
+                print(("  Collocation: [%6.4f] %r+%r" % (ll, typ1, typ2)))
 
         self._finalized = True
 
@@ -889,7 +886,7 @@ class PunktTrainer(PunktBaseClass):
         positions.
         """
         # 'initial' or 'internal' or 'unknown'
-        context = 'internal'
+        context = "internal"
         tokens = list(tokens)
 
         for aug_tok in tokens:
@@ -897,13 +894,13 @@ class PunktTrainer(PunktBaseClass):
             # that it's a sentence break.  But err on the side of
             # caution (by not positing a sentence break) if we just
             # saw an abbreviation.
-            if aug_tok.parastart and context != 'unknown':
-                context = 'initial'
+            if aug_tok.parastart and context != "unknown":
+                context = "initial"
 
             # If we're at the beginning of a line, then we can't decide
             # between 'internal' and 'initial'.
-            if aug_tok.linestart and context == 'internal':
-                context = 'unknown'
+            if aug_tok.linestart and context == "internal":
+                context = "unknown"
 
             # Find the case-normalized type of the token.  If it's a
             # sentence-final token, strip off the period.
@@ -917,13 +914,13 @@ class PunktTrainer(PunktBaseClass):
             # Decide whether the next word is at a sentence boundary.
             if aug_tok.sentbreak:
                 if not (aug_tok.is_number or aug_tok.is_initial):
-                    context = 'initial'
+                    context = "initial"
                 else:
-                    context = 'unknown'
+                    context = "unknown"
             elif aug_tok.ellipsis or aug_tok.abbr:
-                context = 'unknown'
+                context = "unknown"
             else:
-                context = 'internal'
+                context = "internal"
 
     # ////////////////////////////////////////////////////////////
     # { Abbreviations
@@ -950,10 +947,10 @@ class PunktTrainer(PunktBaseClass):
         for typ in types:
             # Check some basic conditions, to rule out words that are
             # clearly not abbrev_types.
-            if not _re_non_punct.search(typ) or typ == '##number##':
+            if not _re_non_punct.search(typ) or typ == "##number##":
                 continue
 
-            if typ.endswith('.'):
+            if typ.endswith("."):
                 if typ in self._params.abbrev_types:
                     continue
                 typ = typ[:-1]
@@ -965,7 +962,7 @@ class PunktTrainer(PunktBaseClass):
 
             # Count how many periods & nonperiods are in the
             # candidate.
-            num_periods = typ.count('.') + 1
+            num_periods = typ.count(".") + 1
             num_nonperiods = len(typ) - num_periods + 1
 
             # Let <a> be the candidate without the period, and <b>
@@ -973,7 +970,7 @@ class PunktTrainer(PunktBaseClass):
             # indicates whether <ab> occurs as a single unit (high
             # value of ll), or as two independent units <a> and
             # <b> (low value of ll).
-            count_with_period = self._type_fdist[typ + '.']
+            count_with_period = self._type_fdist[typ + "."]
             count_without_period = self._type_fdist[typ]
             ll = self._dunning_log_likelihood(
                 count_with_period + count_without_period,
@@ -1003,7 +1000,7 @@ class PunktTrainer(PunktBaseClass):
         This fails to include abbreviations otherwise found as "rare".
         """
         self._params.clear_abbrevs()
-        tokens = (typ for typ in self._type_fdist if typ and typ.endswith('.'))
+        tokens = (typ for typ in self._type_fdist if typ and typ.endswith("."))
         for abbr, score, is_add in self._reclassify_abbrev_types(tokens):
             if score >= self.ABBREV:
                 self._params.abbrev_types.add(abbr)
@@ -1156,8 +1153,8 @@ class PunktTrainer(PunktBaseClass):
                 continue
 
             col_count = self._collocation_fdist[types]
-            typ1_count = self._type_fdist[typ1] + self._type_fdist[typ1 + '.']
-            typ2_count = self._type_fdist[typ2] + self._type_fdist[typ2 + '.']
+            typ1_count = self._type_fdist[typ1] + self._type_fdist[typ1 + "."]
+            typ2_count = self._type_fdist[typ2] + self._type_fdist[typ2 + "."]
             if (
                 typ1_count > 1
                 and typ2_count > 1
@@ -1201,7 +1198,7 @@ class PunktTrainer(PunktBaseClass):
                 continue
 
             typ_at_break_count = self._sent_starter_fdist[typ]
-            typ_count = self._type_fdist[typ] + self._type_fdist[typ + '.']
+            typ_count = self._type_fdist[typ] + self._type_fdist[typ + "."]
             if typ_count < typ_at_break_count:
                 # needed after freq_threshold
                 continue
@@ -1260,7 +1257,7 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
         given. Repeated calls to this method destroy previous parameters. For
         incremental training, instantiate a separate PunktTrainer instance.
         """
-        if not isinstance(train_text, string_types):
+        if not isinstance(train_text, str):
             return train_text
         return PunktTrainer(
             train_text, lang_vars=self._lang_vars, token_cls=self._Token
@@ -1285,7 +1282,7 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
         """
 
         for match in self._lang_vars.period_context_re().finditer(text):
-            decision_text = match.group() + match.group('after_tok')
+            decision_text = match.group() + match.group("after_tok")
             tokens = self._tokenize_words(decision_text)
             tokens = list(self._annotate_first_pass(tokens))
             while not tokens[0].period_final:
@@ -1333,12 +1330,12 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
     def _slices_from_text(self, text):
         last_break = 0
         for match in self._lang_vars.period_context_re().finditer(text):
-            context = match.group() + match.group('after_tok')
+            context = match.group() + match.group("after_tok")
             if self.text_contains_sentbreak(context):
                 yield slice(last_break, match.end())
-                if match.group('next_tok'):
+                if match.group("next_tok"):
                     # next sentence starts after whitespace
-                    last_break = match.start('next_tok')
+                    last_break = match.start("next_tok")
                 else:
                     # next sentence starts at following punctuation
                     last_break = match.end()
@@ -1445,9 +1442,9 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
         pos = 0
 
         # A regular expression that finds pieces of whitespace:
-        WS_REGEXP = re.compile(r'\s*')
+        WS_REGEXP = re.compile(r"\s*")
 
-        sentence = ''
+        sentence = ""
         for aug_tok in tokens:
             tok = aug_tok.tok
 
@@ -1461,7 +1458,7 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
             # token doesn't match, see if adding whitespace helps.
             # If so, then use the version with whitespace.
             if text[pos : pos + len(tok)] != tok:
-                pat = '\s*'.join(re.escape(c) for c in tok)
+                pat = r"\s*".join(re.escape(c) for c in tok)
                 m = re.compile(pat).match(text, pos)
                 if m:
                     tok = m.group()
@@ -1480,23 +1477,23 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
             # If we're at a sentence break, then start a new sentence.
             if aug_tok.sentbreak:
                 yield sentence
-                sentence = ''
+                sentence = ""
 
-        # If the last sentence is emtpy, discard it.
+        # If the last sentence is empty, discard it.
         if sentence:
             yield sentence
 
     # [XX] TESTING
     def dump(self, tokens):
-        print('writing to /tmp/punkt.new...')
-        with open('/tmp/punkt.new', 'w') as outfile:
+        print("writing to /tmp/punkt.new...")
+        with open("/tmp/punkt.new", "w") as outfile:
             for aug_tok in tokens:
                 if aug_tok.parastart:
-                    outfile.write('\n\n')
+                    outfile.write("\n\n")
                 elif aug_tok.linestart:
-                    outfile.write('\n')
+                    outfile.write("\n")
                 else:
-                    outfile.write(' ')
+                    outfile.write(" ")
 
                 outfile.write(str(aug_tok))
 
@@ -1504,7 +1501,7 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
     # { Customization Variables
     # ////////////////////////////////////////////////////////////
 
-    PUNCTUATION = tuple(';:,.!?')
+    PUNCTUATION = tuple(";:,.!?")
 
     # ////////////////////////////////////////////////////////////
     # { Annotation Procedures
@@ -1573,7 +1570,7 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
         # [4.3. Token-Based Detection of Initials and Ordinals]
         # Check if any initials or ordinals tokens that are marked
         # as sentbreaks should be reclassified as abbreviations.
-        if tok_is_initial or typ == '##number##':
+        if tok_is_initial or typ == "##number##":
 
             # [4.1.1. Orthographic Heuristic] Check if there's
             # orthogrpahic evidence about whether the next word
@@ -1592,7 +1589,7 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
             # heuristc is unknown, and next word is always
             # capitalized, then mark as abbrev (eg: J. Bach).
             if (
-                is_sent_starter == 'unknown'
+                is_sent_starter == "unknown"
                 and tok_is_initial
                 and aug_tok2.first_upper
                 and not (self._params.ortho_context[next_typ] & _ORTHO_LC)
@@ -1633,10 +1630,10 @@ class PunktSentenceTokenizer(PunktBaseClass, TokenizerI):
             return False
 
         # Otherwise, we're not sure.
-        return 'unknown'
+        return "unknown"
 
 
-DEBUG_DECISION_FMT = '''Text: %(text)r (at offset %(period_index)d)
+DEBUG_DECISION_FMT = """Text: %(text)r (at offset %(period_index)d)
 Sentence break? %(break_decision)s (%(reason)s)
 Collocation? %(collocation)s
 %(type1)r:
@@ -1646,7 +1643,7 @@ Collocation? %(collocation)s
     known sentence starter: %(type2_is_sent_starter)s
     orthographic heuristic suggests is a sentence starter? %(type2_ortho_heuristic)s
     orthographic contexts in training: %(type2_ortho_contexts)s
-'''
+"""
 
 
 def format_debug_decision(d):
@@ -1656,7 +1653,7 @@ def format_debug_decision(d):
 def demo(text, tok_cls=PunktSentenceTokenizer, train_cls=PunktTrainer):
     """Builds a punkt model and applies it to the same text"""
     cleanup = (
-        lambda s: re.compile(r'(?:\r|^\s+)', re.MULTILINE).sub('', s).replace('\n', ' ')
+        lambda s: re.compile(r"(?:\r|^\s+)", re.MULTILINE).sub("", s).replace("\n", " ")
     )
     trainer = train_cls()
     trainer.INCLUDE_ALL_COLLOCS = True
